km3pipe.db.DBManager
====================

.. currentmodule:: km3pipe.db

.. autoclass:: DBManager

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DBManager.__init__
      ~DBManager.ahrs
      ~DBManager.datalog
      ~DBManager.detx
      ~DBManager.login
      ~DBManager.request_permanent_session
      ~DBManager.request_sid_cookie
      ~DBManager.restore_session
      ~DBManager.run_table
      ~DBManager.trigger_setup
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~DBManager.detectors
      ~DBManager.doms
      ~DBManager.opener
      ~DBManager.parameters
   
   